@@ -1,7 +1,55 @@
 package App::gh;
-
 use warnings;
 use strict;
+use Exporter::Lite;
+
+our @EXPORT = qw(parse_config parse_options get_github_auth);
+
+sub parse_config {
+    my ($file) = @_;
+    open FH , "<" , $file;
+    local $/;
+    my $content = <FH>;
+    close FH;
+    my @parts = split /(?=\[.*?\])/,$content;
+
+
+    my %config;
+
+    for my $part ( @parts ) {
+        if( $part =~ /^\[(\w+)\s+["'](\w+)["']\]/g ) {
+            my ($o1 , $o2 ) = ($1, $2);
+            $config{ $o1 } ||= {};
+            $config{ $o1 }->{ $o2 } 
+                = parse_options( $part );
+        }
+        elsif( $part =~ /^\[(.*?)\]/g  ) {
+            my $key = $1;
+            my $options = parse_options( $part );
+            $config{ $key } = $options;
+        }
+    }
+    return \%config;
+}
+
+sub parse_options {
+    my $part = shift;
+    my $options;
+    while(  $part =~ /^\s*(.*?)\s*=\s*(.*?)\s*$/gm ) {
+        my ($name,$value) = ($1,$2);
+        $options->{ $name } = $value;
+    }
+    return $options;
+}
+
+sub get_github_auth {
+    my $config = parse_config $ENV{HOME} . "/.gitconfig";
+    return $config->{github};
+}
+
+
+
+__END__
 
 =head1 NAME
 
@@ -9,11 +57,11 @@ App::gh - An apt-like Github clone utility.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -22,9 +70,9 @@ list all repository of c9s:
 
     $ gh list c9s
 
-if you dont want text wrapped:
+if you want text wrapped:
 
-    $ NO_WRAP=1 gh list c9s
+    $ WRAP=1 gh list c9s
 
 clone Plack repository from miyagawa:
 
@@ -56,10 +104,15 @@ to clone all repository of miyagawa:
 
     $ gh cloneall clkao ro  # read-only
 
-to fork project
+to fork project:
 
     $ gh fork clkao AnyMQ
 
+to fork current project:
+
+    $ cd miyagawa/Tatsumaki
+    $ gh fork
+
 =head1 AUTHOR
 
 Cornelius, C<< <cornelius.howl at gmail.com> >>
@@ -116,4 +169,6 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
+
+
 1; # End of App::gh
